@@ -5,7 +5,11 @@ class Engine:
     Apple = "https://www.apple.com/search/{query}"
     Ask = "https://www.ask.com/web?q={query}"
     AOL = "https://search.aol.co.uk/aol/search?q={query}"
-    Amazon = "https://www.amazon.com/s?k={query}"   
+    Amazon = "https://www.amazon.com/s?k={query}" 
+    Altassian = "https://www.atlassian.com/search?q={query}"
+    AOL = "https://search.aol.com/aol/search?q={query}"
+    Amazon = "https://www.amazon.com/s?k={query}"  
+    AmazonWebServices = "https://aws.amazon.com/search/?searchQuery={query}"
     Bing = "https://www.bing.com/search?q={query}"
     ChromeWebStore = "https://chrome.google.com/webstore/search/{query}"
     Crunchyroll = "https://www.crunchyroll.com/search?q={query}"
@@ -33,6 +37,7 @@ class Engine:
     PyPi = "https://pypi.org/search/?q={query}"
     Quora = "https://www.quora.com/search?q={query}"
     Replit = "https://replit.com/search?q={query}"
+    Reddit = "https://www.reddit.com/search/?q={query}"
     Spotify = "https://open.spotify.com/search/{query}"
     StackOverflow = "https://www.stackoverflow.com/search?q={query}"
     TikTok = "https://www.tiktok.com/search?q={query}"
